dispatch Package
================

:mod:`dispatch` Package
-----------------------

.. automodule:: thriftpool.utils.dispatch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`saferef` Module
---------------------

.. automodule:: thriftpool.utils.dispatch.saferef
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`signal` Module
--------------------

.. automodule:: thriftpool.utils.dispatch.signal
    :members:
    :undoc-members:
    :show-inheritance:

